@@ -1,4 +1,4 @@
-from netqasm.sdk.epr_socket import EPRSocket, EPRType
+from netqasm.sdk.epr_socket import EPRSocket
 from netqasm.sdk.external import NetQASMConnection
 
 
@@ -17,7 +17,7 @@ def main(app_config=None):
     num_pairs = 10
 
     with server:
-        outcomes = epr_socket.recv(number=num_pairs, tp=EPRType.M)
+        outcomes = epr_socket.recv_measure(number=num_pairs)
 
     for outcome in outcomes:
         print(f"Server: {outcome.measurement_outcome}")
